@@ -99,5 +99,3 @@ def DefineScale(height,width):
     scale_factor = ((dim[0]/height) + (dim[1]/width)  )/2
     return scale_factor
 
-def CountDefects(contours):
-    return len(contours)
\ No newline at end of file
